.. _Supported solvers:

*****************
Supported solvers
*****************

Solvers that are detected as installed on your machine are listed in:

.. autodata:: qpsolvers.available_solvers

CVXOPT
======

.. automodule:: qpsolvers.solvers.cvxopt_
    :members:

DAQP
======

.. automodule:: qpsolvers.solvers.daqp_
    :members:

ECOS
====

.. automodule:: qpsolvers.solvers.ecos_
    :members:

Gurobi
======

.. automodule:: qpsolvers.solvers.gurobi_
    :members:

HiGHS
=====

.. automodule:: qpsolvers.solvers.highs_
    :members:

HPIPM
=====

.. automodule:: qpsolvers.solvers.hpipm_
    :members:

MOSEK
=====

.. automodule:: qpsolvers.solvers.mosek_
    :members:

OSQP
====

.. automodule:: qpsolvers.solvers.osqp_
    :members:

PIQP
======

.. automodule:: qpsolvers.solvers.piqp_
    :members:

ProxQP
======

.. automodule:: qpsolvers.solvers.proxqp_
    :members:

qpOASES
=======

.. automodule:: qpsolvers.solvers.qpoases_
    :members:

qpSWIFT
=======

.. automodule:: qpsolvers.solvers.qpswift_
    :members:

quadprog
========

.. automodule:: qpsolvers.solvers.quadprog_
    :members:

SCS
===

.. automodule:: qpsolvers.solvers.scs_
    :members:
